@@ -31,6 +31,9 @@ V1_10_5 = 'v1.10.5'
 V1_10_6 = 'v1.10.6'
 V1_10_7 = 'v1.10.7'
 V1_10_8 = 'v1.10.8'
+V1_10_9 = 'v1.10.9'
+V1_10_10 = 'v1.10.10'
+V1_10_11 = 'v1.10.11'
 
 
 LINUX = 'linux'
@@ -101,7 +104,7 @@ def check_subprocess_call(command, message=None, stderr=subprocess.STDOUT, **pro
 
     return subprocess.check_call(
         command,
-        stderr=subprocess.STDOUT,
+        stderr=stderr,
         **proc_kwargs
     )
 
@@ -113,7 +116,7 @@ def check_subprocess_output(command, message=None, stderr=subprocess.STDOUT, **p
 
     return subprocess.check_output(
         command,
-        stderr=subprocess.STDOUT,
+        stderr=stderr,
         **proc_kwargs
     )
 
@@ -278,7 +281,7 @@ def install_from_source_code_release(identifier):
     build_from_source_code(identifier)
 
     executable_path = get_executable_path(identifier)
-    assert os.path.exists(executable_path), "Executable not found @".format(executable_path)
+    assert os.path.exists(executable_path), "Executable not found @ {0}".format(executable_path)
 
     check_version_command = [executable_path, 'version']
 
@@ -314,6 +317,9 @@ install_v1_10_5 = functools.partial(install_from_source_code_release, V1_10_5)
 install_v1_10_6 = functools.partial(install_from_source_code_release, V1_10_6)
 install_v1_10_7 = functools.partial(install_from_source_code_release, V1_10_7)
 install_v1_10_8 = functools.partial(install_from_source_code_release, V1_10_8)
+install_v1_10_9 = functools.partial(install_from_source_code_release, V1_10_9)
+install_v1_10_10 = functools.partial(install_from_source_code_release, V1_10_10)
+install_v1_10_11 = functools.partial(install_from_source_code_release, V1_10_11)
 
 
 INSTALL_FUNCTIONS = {
@@ -339,6 +345,9 @@ INSTALL_FUNCTIONS = {
         V1_10_6: install_v1_10_6,
         V1_10_7: install_v1_10_7,
         V1_10_8: install_v1_10_8,
+        V1_10_9: install_v1_10_9,
+        V1_10_10: install_v1_10_10,
+        V1_10_11: install_v1_10_11,
     },
     OSX: {
         V1_9_14: install_v1_9_14,
@@ -362,6 +371,9 @@ INSTALL_FUNCTIONS = {
         V1_10_6: install_v1_10_6,
         V1_10_7: install_v1_10_7,
         V1_10_8: install_v1_10_8,
+        V1_10_9: install_v1_10_9,
+        V1_10_10: install_v1_10_10,
+        V1_10_11: install_v1_10_11,
     }
 }
 
